==> jboss-eap-6.1.0-src.zip: jboss-eap-6.1-src/arquillian/container-managed-domain/src/test/java/org/jboss/as/arquillian/container/domain/managed/test/ManagedDomainTwoTestCase.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2011 Red Hat Inc. and/or its affiliates and other contributors
 * as indicated by the @authors tag. All rights reserved.
 * See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.as.arquillian.container.domain.managed.test;

import org.jboss.arquillian.container.test.api.ContainerController;
import org.jboss.arquillian.container.test.api.Deployment;
import org.jboss.arquillian.container.test.api.RunAsClient;
import org.jboss.arquillian.container.test.api.TargetsContainer;
import org.jboss.arquillian.junit.Arquillian;
import org.jboss.arquillian.junit.InSequence;
import org.jboss.arquillian.test.api.ArquillianResource;
import org.jboss.shrinkwrap.api.ShrinkWrap;
import org.jboss.shrinkwrap.api.spec.WebArchive;
import org.junit.Test;
import org.junit.runner.RunWith;

/**
 * For Domain server DeployableContianer implementations, the DeployableContainer will register 
 * all groups/individual servers it controls as Containers in Arquillians Registry during start.
 * 
 * @author <a href="mailto:aslak@redhat.com">Aslak Knutsen</a>
 * @version $Revision: $
 */
@RunWith(Arquillian.class)
public class ManagedDomainTwoTestCase {

    @Deployment @TargetsContainer("backend")
    public static WebArchive create1() {
        return ShrinkWrap.create(WebArchive.class);
    }

    @ArquillianResource
    private ContainerController controller;
    
    @Test @InSequence(1) @RunAsClient
    public void shouldBeAbleToStartServer() throws Exception {
        controller.start("backend-2");
    }

    @Test @InSequence(2) @TargetsContainer("backend-2")
    public void shouldBeAbleToRunInStartedServer() {
        System.out.println(".. in container ..");
    }
}

==> jboss-eap-6.4.19-src.zip: jboss-eap-6.4-src/arquillian/container-managed-domain/src/test/java/org/jboss/as/arquillian/container/domain/managed/test/ManagedDomainTwoTestCase.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2011 Red Hat Inc. and/or its affiliates and other contributors
 * as indicated by the @authors tag. All rights reserved.
 * See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.as.arquillian.container.domain.managed.test;

import org.jboss.arquillian.container.test.api.ContainerController;
import org.jboss.arquillian.container.test.api.Deployment;
import org.jboss.arquillian.container.test.api.RunAsClient;
import org.jboss.arquillian.container.test.api.TargetsContainer;
import org.jboss.arquillian.junit.Arquillian;
import org.jboss.arquillian.junit.InSequence;
import org.jboss.arquillian.test.api.ArquillianResource;
import org.jboss.shrinkwrap.api.ShrinkWrap;
import org.jboss.shrinkwrap.api.spec.WebArchive;
import org.junit.Test;
import org.junit.runner.RunWith;

/**
 * For Domain server DeployableContainer implementations, the DeployableContainer will register
 * all groups/individual servers it controls as Containers in Arquillian's Registry during start.
 * 
 * @author <a href="mailto:aslak@redhat.com">Aslak Knutsen</a>
 * @version $Revision: $
 */
@RunWith(Arquillian.class)
public class ManagedDomainTwoTestCase {

    @Deployment @TargetsContainer("backend")
    public static WebArchive create1() {
        return ShrinkWrap.create(WebArchive.class);
    }

    @ArquillianResource
    private ContainerController controller;
    
    @Test @InSequence(1) @RunAsClient
    public void shouldBeAbleToStartServer() throws Exception {
        controller.start("backend-2");
    }

    @Test @InSequence(2) @TargetsContainer("backend-2")
    public void shouldBeAbleToRunInStartedServer() {
        System.out.println(".. in container ..");
    }
}
